==> huaweicloudsdkbms-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/os_reinstall_body.py <==
# coding: utf-8

import re
import six





class OsReinstallBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'os_reinstall': 'OsReinstall'
    }

    attribute_map = {
        'os_reinstall': 'os-reinstall'
    }

    def __init__(self, os_reinstall=None):
        """OsReinstallBody - a model defined in huaweicloud sdk"""
        
        

        self._os_reinstall = None
        self.discriminator = None

        self.os_reinstall = os_reinstall

    @property
    def os_reinstall(self):
        """Gets the os_reinstall of this OsReinstallBody.


        :return: The os_reinstall of this OsReinstallBody.
        :rtype: OsReinstall
        """
        return self._os_reinstall

    @os_reinstall.setter
    def os_reinstall(self, os_reinstall):
        """Sets the os_reinstall of this OsReinstallBody.


        :param os_reinstall: The os_reinstall of this OsReinstallBody.
        :type: OsReinstall
        """
        self._os_reinstall = os_reinstall

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OsReinstallBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbms-3.0.54-py2.py3-none-any.whl: huaweicloudsdkbms/v1/model/os_reinstall_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class OsReinstallBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'os_reinstall': 'OsReinstall'
    }

    attribute_map = {
        'os_reinstall': 'os-reinstall'
    }

    def __init__(self, os_reinstall=None):
        """OsReinstallBody - a model defined in huaweicloud sdk"""
        
        

        self._os_reinstall = None
        self.discriminator = None

        self.os_reinstall = os_reinstall

    @property
    def os_reinstall(self):
        """Gets the os_reinstall of this OsReinstallBody.


        :return: The os_reinstall of this OsReinstallBody.
        :rtype: OsReinstall
        """
        return self._os_reinstall

    @os_reinstall.setter
    def os_reinstall(self, os_reinstall):
        """Sets the os_reinstall of this OsReinstallBody.


        :param os_reinstall: The os_reinstall of this OsReinstallBody.
        :type: OsReinstall
        """
        self._os_reinstall = os_reinstall

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OsReinstallBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
